@@ -535,7 +535,7 @@ class FileIndex(FieldsetIndex):
                 self = cls.from_indexpath(indexpath)
                 if (
                     getattr(self, "index_keys", None) == index_keys
-                    and getattr(self, "filestream", None) == filestream
+                    and getattr(self, "fieldset", None) == filestream
                     and getattr(self, "index_protocol_version", None) == ALLOWED_PROTOCOL_VERSION
                 ):
                     return self
@@ -549,4 +549,7 @@ class FileIndex(FieldsetIndex):
         return cls.from_fieldset(filestream, index_keys, computed_keys)
 
     def source(self) -> str:
-        return os.path.relpath(self.fieldset.path)
+        try:
+            return os.path.relpath(self.fieldset.path)
+        except ValueError:
+            return os.path.basename(self.fieldset.path)
