@@ -32,6 +32,22 @@ def test_cfgrib_cli_to_netcdf(tmpdir: py.path.local) -> None:
     assert res.exit_code == 0
     assert res.output == ""
 
+    backend_kwargs = '{"time_dims": ["time"]}'
+    res = runner.invoke(__main__.cfgrib_cli, ["to_netcdf", TEST_DATA, "-b", backend_kwargs])
+
+    assert res.exit_code == 0
+    assert res.output == ""
+
+    backend_kwargs_json = tmpdir.join("temp.json")
+    with open(backend_kwargs_json, "w") as f:
+        f.write(backend_kwargs)
+    res = runner.invoke(
+        __main__.cfgrib_cli, ["to_netcdf", TEST_DATA, "-b", str(backend_kwargs_json)]
+    )
+
+    assert res.exit_code == 0
+    assert res.output == ""
+
 
 def test_cfgrib_cli_dump() -> None:
     runner = click.testing.CliRunner()
